Djem
====

|build| |coverage| |docs| |pypi| |license|
|pyversions| |djversions|

A collection of useful stuff for Django projects. It supports Django 3.2+ and Python 3.9+.


Installation
------------

Install the latest stable version from PyPI:

.. code-block:: bash

    pip install djem


Documentation
-------------

Full documentation can be found at: https://djem.readthedocs.io.


.. |build| image:: https://github.com/oogles/djem/actions/workflows/test.yml/badge.svg
    :alt: Build status
    :target: https://github.com/oogles/djem/actions/

.. |coverage| image:: https://coveralls.io/repos/github/oogles/djem/badge.svg?branch=main
    :alt: Test suite coverage
    :target: https://coveralls.io/github/oogles/djem?branch=main

.. |docs| image:: https://readthedocs.org/projects/djem/badge/?version=latest
    :alt: Latest documentation build
    :target: http://djem.readthedocs.io/en/latest/?badge=latest

.. |pypi| image:: https://img.shields.io/pypi/v/djem.svg
    :alt: Latest release version
    :target: https://pypi.org/project/djem/

.. |license| image:: https://img.shields.io/pypi/l/djem.svg
    :alt: License

.. |pyversions| image:: https://img.shields.io/pypi/pyversions/djem.svg
    :alt: Supported Python versions

.. |djversions| image:: https://img.shields.io/pypi/djversions/djem.svg
    :alt: Supported Django versions
